# Standard library imports
from setuptools import setup, find_packages

setup(
    name='vproces',
    include_package_data=True,
    packages = find_packages(),
    version='0.0.6',
    author='Wojciech A',
    author_email='wa@gmail.com',
    license='LICENSE.txt',
    description='An awesome package that does something',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    python_requires='>=3.6, <4',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3 :: Only'
    ],
    install_requires=[
        'opencv-python>=4.5.5'
    ]
)



import cv2
import numpy as np


__all__ = ['hstack', 'vstack']


def vstack(imgs):
    min_width = min([img.shape[1] for img in imgs])

    imgs_to_stack = []
    for img in imgs:
        if img.shape[1] != min_width:
            f = min_width / img.shape[1]
            img_resized = cv2.resize(img, (0, 0), fx=f, fy=f)
            imgs_to_stack.append(img_resized)
        else:
            imgs_to_stack.append(img)

    stacked = np.vstack(imgs_to_stack)
    return stacked


def hstack(imgs):
    min_height = min([img.shape[0] for img in imgs])

    imgs_to_stack = []
    for img in imgs:
        if img.shape[0] != min_height:
            f = min_height / img.shape[0]
            img_resized = cv2.resize(img, (0, 0), fx=f, fy=f)
            imgs_to_stack.append(img_resized)
        else:
            imgs_to_stack.append(img)

    stacked = np.hstack(imgs_to_stack)
    return stacked


if __name__ == '__main__':
    img_paths = ['D:/data/asd/images/pano1 kopia.png',
                 'D:/data/asd/images/pano1.png']

    imgs = [cv2.imread(p) for p in img_paths]

    stacked = vstack(imgs)

    cv2.imshow('stacked', stacked)
    cv2.waitKey(0)
